@@ -15,11 +15,11 @@ OBS_PROJECT_BETA=home:ivaradi:beta
 OBS_PACKAGE=nextcloud-desktop
 
 if test "${DRONE_TARGET_BRANCH}" = "stable-2.6"; then
-    UBUNTU_DISTRIBUTIONS="bionic focal hirsute impish"
+    UBUNTU_DISTRIBUTIONS="bionic focal jammy kinetic"
     DEBIAN_DISTRIBUTIONS="buster stretch testing"
 else
-    UBUNTU_DISTRIBUTIONS="focal hirsute impish"
-    DEBIAN_DISTRIBUTIONS="testing"
+    UBUNTU_DISTRIBUTIONS="jammy kinetic"
+    DEBIAN_DISTRIBUTIONS="bullseye testing"
 fi
 
 pull_request=${DRONE_PULL_REQUEST:=master}
