@@ -71,16 +71,16 @@ struct CmdOptions
     QString user;
     QString password;
     QString proxy;
-    bool silent;
-    bool trustSSL;
-    bool useNetrc;
-    bool interactive;
-    bool ignoreHiddenFiles;
+    bool silent = false;
+    bool trustSSL = false;
+    bool useNetrc = false;
+    bool interactive = false;
+    bool ignoreHiddenFiles = false;
     QString exclude;
     QString unsyncedfolders;
-    int restartTimes;
-    int downlimit;
-    int uplimit;
+    int restartTimes = 0;
+    int downlimit = 0;
+    int uplimit = 0;
 };
 
 // we can't use csync_set_userdata because the SyncEngine sets it already.
@@ -118,7 +118,7 @@ private:
     DWORD mode = 0;
     HANDLE hStdin;
 #else
-    termios tios;
+    termios tios{};
 #endif
 };
 
@@ -137,8 +137,6 @@ class HttpCredentialsText : public HttpCredentials
 public:
     HttpCredentialsText(const QString &user, const QString &password)
         : HttpCredentials(user, password)
-        , // FIXME: not working with client certs yet (qknight)
-        _sslTrusted(false)
     {
     }
 
@@ -161,7 +159,8 @@ public:
     }
 
 private:
-    bool _sslTrusted;
+    // FIXME: not working with client certs yet (qknight)
+    bool _sslTrusted{false};
 };
 #endif /* TOKEN_AUTH_ONLY */
 
@@ -440,6 +439,7 @@ int main(int argc, char **argv)
 
     account->setUrl(hostUrl);
     account->setSslErrorHandler(sslErrorHandler);
+    account->setTrustCertificates(options.trustSSL);
 
     QEventLoop loop;
     auto *job = new JsonApiJob(account, QLatin1String("ocs/v1.php/cloud/capabilities"));
