@@ -122,22 +122,22 @@ private:
 
     Theme *_theme;
 
-    bool _helpOnly;
-    bool _versionOnly;
+    bool _helpOnly = false;
+    bool _versionOnly = false;
 
     QElapsedTimer _startedAt;
 
     // options from command line:
-    bool _showLogWindow;
+    bool _showLogWindow = false;
     bool _quitInstance = false;
     QString _logFile;
     QString _logDir;
-    int _logExpire;
-    bool _logFlush;
-    bool _logDebug;
-    bool _userTriggeredConnect;
-    bool _debugMode;
-    bool _backgroundMode;
+    int _logExpire = 0;
+    bool _logFlush = false;
+    bool _logDebug = true;
+    bool _userTriggeredConnect = false;
+    bool _debugMode = false;
+    bool _backgroundMode = false;
     QUrl _editFileLocallyUrl;
 
     ClientProxy _proxy;
