@@ -13,7 +13,7 @@
  */
 
 #include <glib.h>
-#include <gio.h>
+#include <gio/gio.h>
 #include <cloudprovidersproviderexporter.h>
 
 #include "cloudproviderwrapper.h"
@@ -26,7 +26,7 @@ CloudProvidersProviderExporter *_providerExporter;
 void on_name_acquired (GDBusConnection *connection, const gchar *name, gpointer user_data)
 {
     Q_UNUSED(name);
-    CloudProviderManager *self;
+    CloudProviderManager *self = nullptr;
     self = static_cast<CloudProviderManager*>(user_data);
     _providerExporter = cloud_providers_provider_exporter_new(connection, LIBCLOUDPROVIDERS_DBUS_BUS_NAME, LIBCLOUDPROVIDERS_DBUS_OBJECT_PATH);
     cloud_providers_provider_exporter_set_name (_providerExporter, APPLICATION_NAME);
