@@ -34,8 +34,8 @@ GSimpleActionGroup *actionGroup = nullptr;
 CloudProviderWrapper::CloudProviderWrapper(QObject *parent, Folder *folder, int folderId, CloudProvidersProviderExporter* cloudprovider) : QObject(parent)
   , _folder(folder)
 {
-    GMenuModel *model;
-    GActionGroup *action_group;
+    GMenuModel *model = nullptr;
+    GActionGroup *action_group = nullptr;
     QString accountName = QString("Folder/%1").arg(folderId);
 
     _cloudProvider = CLOUD_PROVIDERS_PROVIDER_EXPORTER(cloudprovider);
@@ -147,7 +147,7 @@ void CloudProviderWrapper::slotUpdateProgress(const QString &folder, const Progr
 
     if (!progress._lastCompletedItem.isEmpty()
             && shouldShowInRecentsMenu(progress._lastCompletedItem)) {
-        GMenuItem* item;
+        GMenuItem* item = nullptr;
         g_menu_remove_all (G_MENU(_recentMenu));
         if(!_recentlyChanged.isEmpty()) {
             QList<QPair<QString, QString>>::iterator i;
@@ -208,8 +208,8 @@ void CloudProviderWrapper::slotSyncFinished(const SyncResult &result)
 
 GMenuModel* CloudProviderWrapper::getMenuModel() {
 
-    GMenu* section;
-    GMenuItem* item;
+    GMenu* section = nullptr;
+    GMenuItem* item = nullptr;
     QString item_label;
 
     _mainMenu = g_menu_new();
@@ -314,7 +314,7 @@ activate_action_pause (GSimpleAction *action,
 {
     Q_UNUSED(parameter);
     auto *self = static_cast<CloudProviderWrapper*>(user_data);
-    GVariant *old_state, *new_state;
+    GVariant *old_state = nullptr, *new_state = nullptr;
 
     old_state = g_action_get_state (G_ACTION (action));
     new_state = g_variant_new_boolean (!(bool)g_variant_get_boolean (old_state));
