@@ -46,7 +46,7 @@ public:
      *
      * @param path Path to request shares for (default all shares)
      */
-    void getShares(const QString &path = "");
+    void getShares(const QString &path = "", const QMap<QString, QString> &params = {});
 
     /**
      * Delete the current Share
@@ -131,6 +131,8 @@ public:
      */
     void getSharedWithMe();
 
+    static const QString _pathForSharesRequest;
+
 signals:
     /**
      * Result of the OCS request
