@@ -80,14 +80,12 @@ void ProxyAuthHandler::handleProxyAuthenticationRequired(
     }
 
     // Find the responsible QNAM if possible.
-    QNetworkAccessManager *sending_qnam = nullptr;
-    QWeakPointer<QNetworkAccessManager> qnam_alive;
+    QPointer<QNetworkAccessManager> sending_qnam = nullptr;
     if (auto account = qobject_cast<Account *>(sender())) {
         // Since we go into an event loop, it's possible for the account's qnam
         // to be destroyed before we get back. We can use this to check for its
         // liveness.
-        qnam_alive = account->sharedNetworkAccessManager();
-        sending_qnam = qnam_alive.data();
+        sending_qnam = account->sharedNetworkAccessManager().data();
     }
     if (!sending_qnam) {
         qCWarning(lcProxy) << "Could not get the sending QNAM for" << sender();
@@ -125,7 +123,6 @@ void ProxyAuthHandler::handleProxyAuthenticationRequired(
     qCInfo(lcProxy) << "got creds for" << _proxy;
     authenticator->setUser(_username);
     authenticator->setPassword(_password);
-    sending_qnam = qnam_alive.data();
     if (sending_qnam) {
         _gaveCredentialsTo.insert(sending_qnam);
         connect(sending_qnam, &QObject::destroyed,
