@@ -28,10 +28,7 @@ RemoteWipe::RemoteWipe(AccountPtr account, QObject *parent)
     : QObject(parent),
       _account(account),
       _appPassword(QString()),
-      _accountRemoved(false),
-      _networkManager(nullptr),
-      _networkReplyCheck(nullptr),
-      _networkReplySuccess(nullptr)
+      _networkManager(nullptr)
 {
     QObject::connect(AccountManager::instance(), &AccountManager::accountRemoved,
                      this, [=](AccountState *) {
@@ -70,7 +67,7 @@ void RemoteWipe::startCheckJobWithAppPassword(QString pwd){
 void RemoteWipe::checkJobSlot()
 {
     auto jsonData = _networkReplyCheck->readAll();
-    QJsonParseError jsonParseError;
+    QJsonParseError jsonParseError{};
     QJsonObject json = QJsonDocument::fromJson(jsonData, &jsonParseError).object();
     bool wipe = false;
 
@@ -148,7 +145,7 @@ void RemoteWipe::notifyServerSuccessJob(AccountState *accountState, bool dataWip
 void RemoteWipe::notifyServerSuccessJobSlot()
 {
     auto jsonData = _networkReplySuccess->readAll();
-    QJsonParseError jsonParseError;
+    QJsonParseError jsonParseError{};
     QJsonObject json = QJsonDocument::fromJson(jsonData, &jsonParseError).object();
     if (_networkReplySuccess->error() != QNetworkReply::NoError ||
             jsonParseError.error != QJsonParseError::NoError) {
