@@ -23,6 +23,8 @@
 #include <QJsonObject>
 #include <QJsonArray>
 
+Q_LOGGING_CATEGORY(lcUserGroupShare, "nextcloud.gui.usergroupshare", QtInfoMsg)
+
 namespace OCC {
 
 /**
@@ -54,14 +56,16 @@ Share::Share(AccountPtr account,
     const QString &ownerDisplayName,
     const QString &path,
     const ShareType shareType,
+    bool isPasswordSet,
     const Permissions permissions,
-    const QSharedPointer<Sharee> shareWith)
+    const ShareePtr shareWith)
     : _account(account)
     , _id(id)
     , _uidowner(uidowner)
     , _ownerDisplayName(ownerDisplayName)
     , _path(path)
     , _shareType(shareType)
+    , _isPasswordSet(isPasswordSet)
     , _permissions(permissions)
     , _shareWith(shareWith)
 {
@@ -97,11 +101,24 @@ Share::ShareType Share::getShareType() const
     return _shareType;
 }
 
-QSharedPointer<Sharee> Share::getShareWith() const
+ShareePtr Share::getShareWith() const
 {
     return _shareWith;
 }
 
+void Share::setPassword(const QString &password)
+{
+    auto * const job = new OcsShareJob(_account);
+    connect(job, &OcsShareJob::shareJobFinished, this, &Share::slotPasswordSet);
+    connect(job, &OcsJob::ocsError, this, &Share::slotSetPasswordError);
+    job->setPassword(getId(), password);
+}
+
+bool Share::isPasswordSet() const
+{
+    return _isPasswordSet;
+}
+
 void Share::setPermissions(Permissions permissions)
 {
     auto *job = new OcsShareJob(_account);
@@ -129,6 +146,12 @@ void Share::deleteShare()
     job->deleteShare(getId());
 }
 
+bool Share::isShareTypeUserGroupEmailRoomOrRemote(const ShareType type)
+{
+    return (type == Share::TypeUser || type == Share::TypeGroup || type == Share::TypeEmail || type == Share::TypeRoom
+        || type == Share::TypeRemote);
+}
+
 void Share::slotDeleted()
 {
     updateFolder(_account, _path);
@@ -140,6 +163,17 @@ void Share::slotOcsError(int statusCode, const QString &message)
     emit serverError(statusCode, message);
 }
 
+void Share::slotPasswordSet(const QJsonDocument &, const QVariant &value)
+{
+    _isPasswordSet = !value.toString().isEmpty();
+    emit passwordSet();
+}
+
+void Share::slotSetPasswordError(int statusCode, const QString &message)
+{
+    emit passwordSetError(statusCode, message);
+}
+
 QUrl LinkShare::getLink() const
 {
     return _url;
@@ -157,11 +191,6 @@ QDate LinkShare::getExpireDate() const
     return _expireDate;
 }
 
-bool LinkShare::isPasswordSet() const
-{
-    return _passwordSet;
-}
-
 LinkShare::LinkShare(AccountPtr account,
     const QString &id,
     const QString &uidowner,
@@ -170,15 +199,18 @@ LinkShare::LinkShare(AccountPtr account,
     const QString &name,
     const QString &token,
     Permissions permissions,
-    bool passwordSet,
+    bool isPasswordSet,
     const QUrl &url,
-    const QDate &expireDate)
-    : Share(account, id, uidowner, ownerDisplayName, path, Share::TypeLink, permissions)
+    const QDate &expireDate,
+    const QString &note,
+    const QString &label)
+    : Share(account, id, uidowner, ownerDisplayName, path, Share::TypeLink, isPasswordSet, permissions)
     , _name(name)
     , _token(token)
-    , _passwordSet(passwordSet)
+    , _note(note)
     , _expireDate(expireDate)
     , _url(url)
+    , _label(label)
 {
 }
 
@@ -202,20 +234,19 @@ QString LinkShare::getNote() const
     return _note;
 }
 
+QString LinkShare::getLabel() const
+{
+    return _label;
+}
+
 void LinkShare::setName(const QString &name)
 {
-    auto *job = new OcsShareJob(_account);
-    connect(job, &OcsShareJob::shareJobFinished, this, &LinkShare::slotNameSet);
-    connect(job, &OcsJob::ocsError, this, &LinkShare::slotOcsError);
-    job->setName(getId(), name);
+    createShareJob(&LinkShare::slotNameSet)->setName(getId(), name);
 }
 
 void LinkShare::setNote(const QString &note)
 {
-    auto *job = new OcsShareJob(_account);
-    connect(job, &OcsShareJob::shareJobFinished, this, &LinkShare::slotNoteSet);
-    connect(job, &OcsJob::ocsError, this, &LinkShare::slotOcsError);
-    job->setNote(getId(), note);
+    createShareJob(&LinkShare::slotNoteSet)->setNote(getId(), note);
 }
 
 void LinkShare::slotNoteSet(const QJsonDocument &, const QVariant &note)
@@ -229,26 +260,22 @@ QString LinkShare::getToken() const
     return _token;
 }
 
-void LinkShare::setPassword(const QString &password)
-{
-    auto *job = new OcsShareJob(_account);
-    connect(job, &OcsShareJob::shareJobFinished, this, &LinkShare::slotPasswordSet);
-    connect(job, &OcsJob::ocsError, this, &LinkShare::slotSetPasswordError);
-    job->setPassword(getId(), password);
-}
-
-void LinkShare::slotPasswordSet(const QJsonDocument &, const QVariant &value)
-{
-    _passwordSet = value.toString() != "";
-    emit passwordSet();
-}
-
 void LinkShare::setExpireDate(const QDate &date)
 {
+    createShareJob(&LinkShare::slotExpireDateSet)->setExpireDate(getId(), date);
+}
+
+void LinkShare::setLabel(const QString &label)
+{
+    createShareJob(&LinkShare::slotLabelSet)->setLabel(getId(), label);
+}
+
+template <typename LinkShareSlot>
+OcsShareJob *LinkShare::createShareJob(const LinkShareSlot slotFunction) {
     auto *job = new OcsShareJob(_account);
-    connect(job, &OcsShareJob::shareJobFinished, this, &LinkShare::slotExpireDateSet);
+    connect(job, &OcsShareJob::shareJobFinished, this, slotFunction);
     connect(job, &OcsJob::ocsError, this, &LinkShare::slotOcsError);
-    job->setExpireDate(getId(), date);
+    return job;
 }
 
 void LinkShare::slotExpireDateSet(const QJsonDocument &reply, const QVariant &value)
@@ -267,17 +294,92 @@ void LinkShare::slotExpireDateSet(const QJsonDocument &reply, const QVariant &va
     emit expireDateSet();
 }
 
-void LinkShare::slotSetPasswordError(int statusCode, const QString &message)
-{
-    emit passwordSetError(statusCode, message);
-}
-
 void LinkShare::slotNameSet(const QJsonDocument &, const QVariant &value)
 {
     _name = value.toString();
     emit nameSet();
 }
 
+void LinkShare::slotLabelSet(const QJsonDocument &, const QVariant &label)
+{
+    if (_label != label.toString()) {
+        _label = label.toString();
+        emit labelSet();
+    }
+}
+
+UserGroupShare::UserGroupShare(AccountPtr account,
+    const QString &id,
+    const QString &owner,
+    const QString &ownerDisplayName,
+    const QString &path,
+    const ShareType shareType,
+    bool isPasswordSet,
+    const Permissions permissions,
+    const ShareePtr shareWith,
+    const QDate &expireDate,
+    const QString &note)
+    : Share(account, id, owner, ownerDisplayName, path, shareType, isPasswordSet, permissions, shareWith)
+    , _note(note)
+    , _expireDate(expireDate)
+{
+    Q_ASSERT(Share::isShareTypeUserGroupEmailRoomOrRemote(shareType));
+    Q_ASSERT(shareWith);
+}
+
+void UserGroupShare::setNote(const QString &note)
+{
+    auto *job = new OcsShareJob(_account);
+    connect(job, &OcsShareJob::shareJobFinished, this, &UserGroupShare::slotNoteSet);
+    connect(job, &OcsJob::ocsError, this, &UserGroupShare::noteSetError);
+    job->setNote(getId(), note);
+}
+
+QString UserGroupShare::getNote() const
+{
+    return _note;
+}
+
+void UserGroupShare::slotNoteSet(const QJsonDocument &, const QVariant &note)
+{
+    _note = note.toString();
+    emit noteSet();
+}
+
+QDate UserGroupShare::getExpireDate() const
+{
+    return _expireDate;
+}
+
+void UserGroupShare::setExpireDate(const QDate &date)
+{
+    if (_expireDate == date) {
+        emit expireDateSet();
+        return;
+    }
+
+    auto *job = new OcsShareJob(_account);
+    connect(job, &OcsShareJob::shareJobFinished, this, &UserGroupShare::slotExpireDateSet);
+    connect(job, &OcsJob::ocsError, this, &UserGroupShare::slotOcsError);
+    job->setExpireDate(getId(), date);
+}
+
+void UserGroupShare::slotExpireDateSet(const QJsonDocument &reply, const QVariant &value)
+{
+    auto data = reply.object().value("ocs").toObject().value("data").toObject();
+
+    /*
+     * If the reply provides a data back (more REST style)
+     * they use this date.
+     */
+    if (data.value("expiration").isString()) {
+        _expireDate = QDate::fromString(data.value("expiration").toString(), "yyyy-MM-dd 00:00:00");
+    } else {
+        _expireDate = value.toDate();
+    }
+    emit expireDateSet();
+}
+
 ShareManager::ShareManager(AccountPtr account, QObject *parent)
     : QObject(parent)
     , _account(account)
@@ -321,7 +423,8 @@ void ShareManager::slotLinkShareCreated(const QJsonDocument &reply)
 void ShareManager::createShare(const QString &path,
     const Share::ShareType shareType,
     const QString shareWith,
-    const Share::Permissions desiredPermissions)
+    const Share::Permissions desiredPermissions,
+    const QString &password)
 {
     auto job = new OcsShareJob(_account);
     connect(job, &OcsJob::ocsError, this, &ShareManager::slotOcsError);
@@ -348,7 +451,7 @@ void ShareManager::createShare(const QString &path,
             auto *job = new OcsShareJob(_account);
             connect(job, &OcsShareJob::shareJobFinished, this, &ShareManager::slotShareCreated);
             connect(job, &OcsJob::ocsError, this, &ShareManager::slotOcsError);
-            job->createShare(path, shareType, shareWith, validPermissions);
+            job->createShare(path, shareType, shareWith, validPermissions, password);
         });
     job->getSharedWithMe();
 }
@@ -358,7 +461,7 @@ void ShareManager::slotShareCreated(const QJsonDocument &reply)
 {
     //Parse share
     auto data = reply.object().value("ocs").toObject().value("data").toObject();
-    QSharedPointer<Share> share(parseShare(data));
+    SharePtr share(parseShare(data));
 
     emit shareCreated(share);
 
@@ -375,32 +478,64 @@ void ShareManager::fetchShares(const QString &path)
 
 void ShareManager::slotSharesFetched(const QJsonDocument &reply)
 {
+    qDebug() << reply;
     auto tmpShares = reply.object().value("ocs").toObject().value("data").toArray();
     const QString versionString = _account->serverVersion();
     qCDebug(lcSharing) << versionString << "Fetched" << tmpShares.count() << "shares";
 
-    QList<QSharedPointer<Share>> shares;
+    QList<SharePtr> shares;
 
     foreach (const auto &share, tmpShares) {
         auto data = share.toObject();
 
         auto shareType = data.value("share_type").toInt();
 
-        QSharedPointer<Share> newShare;
+        SharePtr newShare;
 
         if (shareType == Share::TypeLink) {
             newShare = parseLinkShare(data);
+        } else if (Share::isShareTypeUserGroupEmailRoomOrRemote(static_cast <Share::ShareType>(shareType))) {
+            newShare = parseUserGroupShare(data);
         } else {
             newShare = parseShare(data);
         }
 
-        shares.append(QSharedPointer<Share>(newShare));
+        shares.append(SharePtr(newShare));
     }
 
     qCDebug(lcSharing) << "Sending " << shares.count() << "shares";
     emit sharesFetched(shares);
 }
 
+QSharedPointer<UserGroupShare> ShareManager::parseUserGroupShare(const QJsonObject &data)
+{
+    ShareePtr sharee(new Sharee(data.value("share_with").toString(),
+        data.value("share_with_displayname").toString(),
+        static_cast<Sharee::Type>(data.value("share_type").toInt())));
+
+    QDate expireDate;
+    if (data.value("expiration").isString()) {
+        expireDate = QDate::fromString(data.value("expiration").toString(), "yyyy-MM-dd 00:00:00");
+    }
+
+    QString note;
+    if (data.value("note").isString()) {
+        note = data.value("note").toString();
+    }
+
+    return QSharedPointer<UserGroupShare>(new UserGroupShare(_account,
+        data.value("id").toVariant().toString(), // "id" used to be an integer, support both
+        data.value("uid_owner").toVariant().toString(),
+        data.value("displayname_owner").toVariant().toString(),
+        data.value("path").toString(),
+        static_cast<Share::ShareType>(data.value("share_type").toInt()),
+        !data.value("password").toString().isEmpty(),
+        static_cast<Share::Permissions>(data.value("permissions").toInt()),
+        sharee,
+        expireDate,
+        note));
+}
+
 QSharedPointer<LinkShare> ShareManager::parseLinkShare(const QJsonObject &data)
 {
     QUrl url;
@@ -422,6 +557,11 @@ QSharedPointer<LinkShare> ShareManager::parseLinkShare(const QJsonObject &data)
     if (data.value("expiration").isString()) {
         expireDate = QDate::fromString(data.value("expiration").toString(), "yyyy-MM-dd 00:00:00");
     }
+    
+    QString note;
+    if (data.value("note").isString()) {
+        note = data.value("note").toString();
+    }
 
     return QSharedPointer<LinkShare>(new LinkShare(_account,
         data.value("id").toVariant().toString(), // "id" used to be an integer, support both
@@ -433,21 +573,24 @@ QSharedPointer<LinkShare> ShareManager::parseLinkShare(const QJsonObject &data)
         (Share::Permissions)data.value("permissions").toInt(),
         data.value("share_with").isString(), // has password?
         url,
-        expireDate));
+        expireDate,
+        note,
+        data.value("label").toString()));
 }
 
-QSharedPointer<Share> ShareManager::parseShare(const QJsonObject &data)
+SharePtr ShareManager::parseShare(const QJsonObject &data) const
 {
-    QSharedPointer<Sharee> sharee(new Sharee(data.value("share_with").toString(),
+    ShareePtr sharee(new Sharee(data.value("share_with").toString(),
         data.value("share_with_displayname").toString(),
         (Sharee::Type)data.value("share_type").toInt()));
 
-    return QSharedPointer<Share>(new Share(_account,
+    return SharePtr(new Share(_account,
         data.value("id").toVariant().toString(), // "id" used to be an integer, support both
         data.value("uid_owner").toVariant().toString(),
         data.value("displayname_owner").toVariant().toString(),
         data.value("path").toString(),
         (Share::ShareType)data.value("share_type").toInt(),
+        !data.value("password").toString().isEmpty(),
         (Share::Permissions)data.value("permissions").toInt(),
         sharee));
 }
