@@ -23,16 +23,18 @@ namespace OCC {
  * Possible permissions, must match the server permission constants
  */
 enum SharePermission {
-    SharePermissionRead = 1,
-    SharePermissionUpdate = 2,
-    SharePermissionCreate = 4,
-    SharePermissionDelete = 8,
-    SharePermissionShare = 16,
-    SharePermissionDefault = 31
+    SharePermissionRead     = 1 << 0,
+    SharePermissionUpdate   = 1 << 1,
+    SharePermissionCreate   = 1 << 2,
+    SharePermissionDelete   = 1 << 3,
+    SharePermissionShare    = 1 << 4,
+    SharePermissionDefault  = 1 << 30
 };
 Q_DECLARE_FLAGS(SharePermissions, SharePermission)
 Q_DECLARE_OPERATORS_FOR_FLAGS(SharePermissions)
 
 } // namespace OCC
 
+Q_DECLARE_METATYPE(OCC::SharePermission)
+
 #endif
