@@ -51,6 +51,7 @@ void registerNotificationCategories(const QString &localizedDownloadString);
 bool canOsXSendUserNotification();
 void sendOsXUserNotification(const QString &title, const QString &message);
 void sendOsXUpdateNotification(const QString &title, const QString &message, const QUrl &webUrl);
+void sendOsXTalkNotification(const QString &title, const QString &message, const QString &token, const QString &replyTo, const AccountStatePtr accountState);
 void setTrayWindowLevelAndVisibleOnAllSpaces(QWindow *window);
 double menuBarThickness();
 #endif
@@ -82,14 +83,8 @@ public:
     enum class WindowPosition { Default, Center };
     Q_ENUM(WindowPosition);
 
-    void setTrayEngine(QQmlApplicationEngine *trayEngine);
-    void create();
-    void showMessage(const QString &title, const QString &message, MessageIcon icon = Information);
-    void showUpdateMessage(const QString &title, const QString &message, const QUrl &webUrl);
-    void setToolTip(const QString &tip);
-    void createCallDialog(const Activity &callNotification, const AccountStatePtr accountState);
-    void createEditFileLocallyLoadingDialog(const QString &fileName);
-    void destroyEditFileLocallyLoadingDialog();
+    enum class FileDetailsPage { Activity, Sharing };
+    Q_ENUM(FileDetailsPage);
 
     Q_REQUIRED_RESULT QString windowTitle() const;
     Q_REQUIRED_RESULT bool useNormalWindow() const;
@@ -97,6 +92,8 @@ public:
     Q_REQUIRED_RESULT bool syncIsPaused() const;
     Q_REQUIRED_RESULT bool isOpen() const;
 
+    bool raiseDialogs();
+
 signals:
     void currentUserChanged();
     void openAccountWizard();
@@ -104,8 +101,8 @@ signals:
     void openHelp();
     void shutdown();
 
-    void openShareDialog(const QString &sharePath, const QString &localPath);
-    void showFileActivityDialog(const QString &objectName, const int objectId);
+    void showFileDetailsPage(const QString &fileLocalPath, const OCC::Systray::FileDetailsPage page);
+    void showFileDetails(AccountState *accountState, const QString &localPath, const OCC::Systray::FileDetailsPage fileDetailsPage);
     void sendChatMessage(const QString &token, const QString &message, const QString &replyTo);
     void showErrorMessageDialog(const QString &error);
 
@@ -113,6 +110,18 @@ signals:
     void isOpenChanged();
 
 public slots:
+    void setTrayEngine(QQmlApplicationEngine *trayEngine);
+    void create();
+
+    void showMessage(const QString &title, const QString &message, QSystemTrayIcon::MessageIcon icon = Information);
+    void showUpdateMessage(const QString &title, const QString &message, const QUrl &webUrl);
+    void showTalkMessage(const QString &title, const QString &message, const QString &replyTo, const QString &token, const AccountStatePtr &accountState);
+    void setToolTip(const QString &tip);
+
+    void createCallDialog(const OCC::Activity &callNotification, const OCC::AccountStatePtr accountState);
+    void createEditFileLocallyLoadingDialog(const QString &fileName);
+    void destroyEditFileLocallyLoadingDialog();
+
     void slotCurrentUserChanged();
 
     void forceWindowInit(QQuickWindow *window) const;
@@ -124,34 +133,42 @@ public slots:
     // only for those managed by the C++ engine
     void destroyDialog(QQuickWindow *window) const;
 
-    void showWindow(WindowPosition position = WindowPosition::Default);
+    void showWindow(OCC::Systray::WindowPosition position = OCC::Systray::WindowPosition::Default);
     void hideWindow();
 
     void setSyncIsPaused(const bool syncIsPaused);
     void setIsOpen(const bool isOpen);
 
+    void createShareDialog(const QString &localPath);
+    void createFileActivityDialog(const QString &localPath);
+
+    void presentShareViewInTray(const QString &localPath);
+
 private slots:
     void slotUnpauseAllFolders();
     void slotPauseAllFolders();
 
 private:
+    // Argument allows user to specify a specific dialog to be raised
+    bool raiseFileDetailDialogs(const QString &localPath = {});
     void setPauseOnAllFoldersHelper(bool pause);
 
     static Systray *_instance;
     Systray();
 
     void setupContextMenu();
+    void createFileDetailsDialog(const QString &localPath);
 
-    QScreen *currentScreen() const;
-    QRect currentScreenRect() const;
-    QPoint computeWindowReferencePoint() const;
-    QPoint computeNotificationReferencePoint(int spacing = 20, NotificationPosition position = NotificationPosition::Default) const;
-    QPoint calcTrayIconCenter() const;
-    TaskBarPosition taskbarOrientation() const;
-    QRect taskbarGeometry() const;
-    QRect computeWindowRect(int spacing, const QPoint &topLeft, const QPoint &bottomRight) const;
-    QPoint computeWindowPosition(int width, int height) const;
-    QPoint computeNotificationPosition(int width, int height, int spacing = 20, NotificationPosition position = NotificationPosition::Default) const;
+    [[nodiscard]] QScreen *currentScreen() const;
+    [[nodiscard]] QRect currentScreenRect() const;
+    [[nodiscard]] QPoint computeWindowReferencePoint() const;
+    [[nodiscard]] QPoint computeNotificationReferencePoint(int spacing = 20, NotificationPosition position = NotificationPosition::Default) const;
+    [[nodiscard]] QPoint calcTrayIconCenter() const;
+    [[nodiscard]] TaskBarPosition taskbarOrientation() const;
+    [[nodiscard]] QRect taskbarGeometry() const;
+    [[nodiscard]] QRect computeWindowRect(int spacing, const QPoint &topLeft, const QPoint &bottomRight) const;
+    [[nodiscard]] QPoint computeWindowPosition(int width, int height) const;
+    [[nodiscard]] QPoint computeNotificationPosition(int width, int height, int spacing = 20, NotificationPosition position = NotificationPosition::Default) const;
 
     bool _isOpen = false;
     bool _syncIsPaused = true;
@@ -162,8 +179,8 @@ private:
     AccessManagerFactory _accessManagerFactory;
 
     QSet<qlonglong> _callsAlreadyNotified;
-
     QPointer<QObject> _editFileLocallyLoadingDialog;
+    QVector<QQuickWindow*> _fileDetailDialogs;
 };
 
 } // namespace OCC
