@@ -92,7 +92,8 @@ void ServerNotificationHandler::slotNotificationsReceived(const QJsonDocument &j
 
         if(json.contains("subjectRichParameters")) {
             const auto richParams = json.value("subjectRichParameters").toObject();
-            for(const auto &key : richParams.keys()) {
+            const auto richParamsKeys = richParams.keys();
+            for(const auto &key : richParamsKeys) {
                 const auto parameterJsonObject = richParams.value(key).toObject();
                 a._subjectRichParameters.insert(key, Activity::RichSubjectParameter{
                                                     parameterJsonObject.value(QStringLiteral("type")).toString(),
@@ -110,30 +111,37 @@ void ServerNotificationHandler::slotNotificationsReceived(const QJsonDocument &j
         if (a._objectType == "chat" || a._objectType == "call" || a._objectType == "room") {
             const auto objectId = json.value("object_id").toString();
             const auto objectIdData = objectId.split("/");
+
+            ActivityLink al;
+            al._label = tr("Reply");
+            al._verb = "REPLY";
+            al._primary = true;
+
             a._talkNotificationData.conversationToken = objectIdData.first();
+
             if (a._objectType == "chat" && objectIdData.size() > 1) {
                 a._talkNotificationData.messageId = objectIdData.last();
             } else {
                 qCInfo(lcServerNotification) << "Replying directly to Talk conversation" << a._talkNotificationData.conversationToken << "will not be possible because the notification doesn't contain the message ID.";
             }
 
-            ActivityLink al;
-            al._label = tr("Reply");
-            al._verb = "REPLY";
-            al._primary = true;
-            a._links.insert(0, al);
+            if (a._subjectRichParameters.contains("user")) {
+
+                // callback then it is the primary action
+                if (a._objectType == "call") {
+                    al._primary = false;
+                }
 
-            if(a._subjectRichParameters.contains("user")) {
                 a._talkNotificationData.userAvatar = ai->account()->url().toString() + QStringLiteral("/index.php/avatar/") + a._subjectRichParameters["user"].id + QStringLiteral("/128");
             }
 
             // We want to serve incoming call dialogs to the user for calls that
-            if(a._objectType == "call" && a._dateTime.secsTo(QDateTime::currentDateTime()) < 120) {
+            if (a._objectType == "call" && a._dateTime.secsTo(QDateTime::currentDateTime()) < 120) {
                 callList.append(a);
             }
-        } 
 
-        a._status = 0;
+            a._links.insert(al._primary? 0 : a._links.size(), al);
+        } 
 
         QUrl link(json.value("link").toString());
         if (!link.isEmpty()) {
@@ -147,22 +155,6 @@ void ServerNotificationHandler::slotNotificationsReceived(const QJsonDocument &j
         }
         a._link = link;
 
-        // Add another action to dismiss notification on server
-        // https://github.com/owncloud/notifications/blob/master/docs/ocs-endpoint-v1.md#deleting-a-notification-for-a-user
-        constexpr auto deleteVerb = "DELETE";
-        const auto itLink = std::find_if(std::cbegin(a._links), std::cend(a._links), [deleteVerb](const ActivityLink& link) {
-            Q_UNUSED(deleteVerb)
-            return link._verb == deleteVerb;
-        });
-        if (itLink == std::cend(a._links)) {
-            ActivityLink al;
-            al._label = tr("Dismiss");
-            al._link = Utility::concatUrlPath(ai->account()->url(), notificationsPath + "/" + QString::number(a._id)).toString();
-            al._verb = deleteVerb;
-            al._primary = false;
-            a._links.append(al);
-        }
-
         list.append(a);
     }
     emit newNotificationList(list);
