@@ -118,7 +118,7 @@ QString Updater::getSystemInfo()
 {
 #ifdef Q_OS_LINUX
     QProcess process;
-    process.start(QLatin1String("lsb_release -a"));
+    process.start(QLatin1String("lsb_release"), { QStringLiteral("-a") });
     process.waitForFinished();
     QByteArray output = process.readAllStandardOutput();
     qCDebug(lcUpdater) << "Sys Info size: " << output.length();
@@ -141,7 +141,7 @@ Updater *Updater::create()
         return nullptr;
     }
 
-#if defined(Q_OS_MAC) && defined(HAVE_SPARKLE)
+#if defined(Q_OS_MACOS) && defined(HAVE_SPARKLE) && defined(BUILD_OWNCLOUD_OSX_BUNDLE)
     return new SparkleUpdater(url);
 #elif defined(Q_OS_WIN32)
     // Also for MSI
