@@ -89,11 +89,11 @@ public:
     Q_REQUIRED_RESULT QString userStatusEmoji() const;
     void setUserStatusEmoji(const QString &emoji);
 
-    QVector<UserStatus> predefinedStatuses() const;
+    [[nodiscard]] QVector<UserStatus> predefinedStatuses() const;
 
     Q_REQUIRED_RESULT QVariantList clearStageTypes() const;
     Q_REQUIRED_RESULT QString clearAtDisplayString() const;
-    Q_INVOKABLE QString clearAtReadable(const UserStatus &status) const;
+    Q_INVOKABLE [[nodiscard]] QString clearAtReadable(const OCC::UserStatus &status) const;
 
     Q_REQUIRED_RESULT QString errorMessage() const;
 
@@ -101,8 +101,8 @@ public slots:
     void setUserIndex(const int userIndex);
     void setUserStatus();
     void clearUserStatus();
-    void setClearAt(const ClearStageType clearStageType);
-    void setPredefinedStatus(const UserStatus &predefinedStatus);
+    void setClearAt(const OCC::UserStatusSelectorModel::ClearStageType clearStageType);
+    void setPredefinedStatus(const OCC::UserStatus &predefinedStatus);
 
 signals:
     void userIndexChanged();
