@@ -107,7 +107,7 @@ WebView::WebView(QWidget *parent)
     }
 
     _webview->setPage(_page);
-    _ui.verticalLayout->addWidget(_webview);
+    _ui.verticalLayout->addWidget(_webview, 1);
 
     connect(_webview, &QWebEngineView::loadProgress, _ui.progressBar, &QProgressBar::setValue);
     connect(_schemeHandler, &WebViewPageUrlSchemeHandler::urlCatched, this, &WebView::urlCatched);
@@ -136,7 +136,10 @@ WebViewPageUrlRequestInterceptor::WebViewPageUrlRequestInterceptor(QObject *pare
 }
 
 void WebViewPageUrlRequestInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info) {
-    info.setHttpHeader("OCS-APIREQUEST", "true");
+    if (info.initiator().isEmpty()) {
+        info.setHttpHeader("OCS-APIREQUEST", "true");
+        qCDebug(lcWizardWebiew()) << info.requestMethod() << "add extra header" << "OCS-APIREQUEST";
+    }
 }
 
 WebViewPageUrlSchemeHandler::WebViewPageUrlSchemeHandler(QObject *parent)
