@@ -44,7 +44,7 @@ class BulkPropagatorJob : public PropagatorJob
     struct UploadFileInfo {
       QString _file; /// I'm still unsure if I should use a SyncFilePtr here.
       QString _path; /// the full path on disk.
-      qint64 _size;
+      qint64 _size = 0LL;
     };
 
     struct BulkUploadItem
