@@ -43,21 +43,25 @@ public:
     enum Scope { UserScope,
         SystemScope };
 
-    QString configPath() const;
-    QString configFile() const;
-    QString excludeFile(Scope scope) const;
+    [[nodiscard]] QString configPath() const;
+    [[nodiscard]] QString configFile() const;
+    [[nodiscard]] QString excludeFile(Scope scope) const;
     static QString excludeFileFromSystem(); // doesn't access config dir
 
     /**
-     * Creates a backup of the file
+     * Creates a backup of any given fileName in the config folder
      *
      * Returns the path of the new backup.
      */
-    QString backup() const;
+    [[nodiscard]] QString backup(const QString &fileName) const;
+    /**
+     * Display warning with a list of the config files that were backed up
+     */
+    [[nodiscard]] bool showConfigBackupWarning() const;
 
     bool exists();
 
-    QString defaultConnection() const;
+    [[nodiscard]] QString defaultConnection() const;
 
     // the certs do not depend on a connection.
     QByteArray caCerts();
@@ -66,49 +70,49 @@ public:
     bool passwordStorageAllowed(const QString &connection = QString());
 
     /* Server poll interval in milliseconds */
-    std::chrono::milliseconds remotePollInterval(const QString &connection = QString()) const;
+    [[nodiscard]] std::chrono::milliseconds remotePollInterval(const QString &connection = QString()) const;
     /* Set poll interval. Value in milliseconds has to be larger than 5000 */
     void setRemotePollInterval(std::chrono::milliseconds interval, const QString &connection = QString());
 
     /* Interval to check for new notifications */
-    std::chrono::milliseconds notificationRefreshInterval(const QString &connection = QString()) const;
+    [[nodiscard]] std::chrono::milliseconds notificationRefreshInterval(const QString &connection = QString()) const;
 
     /* Force sync interval, in milliseconds */
-    std::chrono::milliseconds forceSyncInterval(const QString &connection = QString()) const;
+    [[nodiscard]] std::chrono::milliseconds forceSyncInterval(const QString &connection = QString()) const;
 
     /**
      * Interval in milliseconds within which full local discovery is required
      *
      * Use -1 to disable regular full local discoveries.
      */
-    std::chrono::milliseconds fullLocalDiscoveryInterval() const;
+    [[nodiscard]] std::chrono::milliseconds fullLocalDiscoveryInterval() const;
 
-    bool monoIcons() const;
+    [[nodiscard]] bool monoIcons() const;
     void setMonoIcons(bool);
 
-    bool promptDeleteFiles() const;
+    [[nodiscard]] bool promptDeleteFiles() const;
     void setPromptDeleteFiles(bool promptDeleteFiles);
 
-    bool crashReporter() const;
+    [[nodiscard]] bool crashReporter() const;
     void setCrashReporter(bool enabled);
 
-    bool automaticLogDir() const;
+    [[nodiscard]] bool automaticLogDir() const;
     void setAutomaticLogDir(bool enabled);
 
-    QString logDir() const;
+    [[nodiscard]] QString logDir() const;
     void setLogDir(const QString &dir);
 
-    bool logDebug() const;
+    [[nodiscard]] bool logDebug() const;
     void setLogDebug(bool enabled);
 
-    int logExpire() const;
+    [[nodiscard]] int logExpire() const;
     void setLogExpire(int hours);
 
-    bool logFlush() const;
+    [[nodiscard]] bool logFlush() const;
     void setLogFlush(bool enabled);
 
     // Whether experimental UI options should be shown
-    bool showExperimentalOptions() const;
+    [[nodiscard]] bool showExperimentalOptions() const;
 
     // proxy settings
     void setProxyType(int proxyType,
@@ -117,86 +121,92 @@ public:
         const QString &user = QString(),
         const QString &pass = QString());
 
-    int proxyType() const;
-    QString proxyHostName() const;
-    int proxyPort() const;
-    bool proxyNeedsAuth() const;
-    QString proxyUser() const;
-    QString proxyPassword() const;
+    [[nodiscard]] int proxyType() const;
+    [[nodiscard]] QString proxyHostName() const;
+    [[nodiscard]] int proxyPort() const;
+    [[nodiscard]] bool proxyNeedsAuth() const;
+    [[nodiscard]] QString proxyUser() const;
+    [[nodiscard]] QString proxyPassword() const;
 
     /** 0: no limit, 1: manual, >0: automatic */
-    int useUploadLimit() const;
-    int useDownloadLimit() const;
+    [[nodiscard]] int useUploadLimit() const;
+    [[nodiscard]] int useDownloadLimit() const;
     void setUseUploadLimit(int);
     void setUseDownloadLimit(int);
     /** in kbyte/s */
-    int uploadLimit() const;
-    int downloadLimit() const;
+    [[nodiscard]] int uploadLimit() const;
+    [[nodiscard]] int downloadLimit() const;
     void setUploadLimit(int kbytes);
     void setDownloadLimit(int kbytes);
     /** [checked, size in MB] **/
-    QPair<bool, qint64> newBigFolderSizeLimit() const;
+    [[nodiscard]] QPair<bool, qint64> newBigFolderSizeLimit() const;
     void setNewBigFolderSizeLimit(bool isChecked, qint64 mbytes);
-    bool useNewBigFolderSizeLimit() const;
-    bool confirmExternalStorage() const;
+    [[nodiscard]] bool useNewBigFolderSizeLimit() const;
+    [[nodiscard]] bool confirmExternalStorage() const;
     void setConfirmExternalStorage(bool);
 
     /** If we should move the files deleted on the server in the trash  */
-    bool moveToTrash() const;
+    [[nodiscard]] bool moveToTrash() const;
     void setMoveToTrash(bool);
 
-    bool showMainDialogAsNormalWindow() const;
+    [[nodiscard]] bool showMainDialogAsNormalWindow() const;
 
     static bool setConfDir(const QString &value);
 
-    bool optionalServerNotifications() const;
+    [[nodiscard]] bool optionalServerNotifications() const;
     void setOptionalServerNotifications(bool show);
 
-    bool showCallNotifications() const;
+    [[nodiscard]] bool showCallNotifications() const;
     void setShowCallNotifications(bool show);
 
-    bool showInExplorerNavigationPane() const;
+    [[nodiscard]] bool showInExplorerNavigationPane() const;
     void setShowInExplorerNavigationPane(bool show);
 
-    int timeout() const;
-    qint64 chunkSize() const;
-    qint64 maxChunkSize() const;
-    qint64 minChunkSize() const;
-    std::chrono::milliseconds targetChunkUploadDuration() const;
+    [[nodiscard]] int timeout() const;
+    [[nodiscard]] qint64 chunkSize() const;
+    [[nodiscard]] qint64 maxChunkSize() const;
+    [[nodiscard]] qint64 minChunkSize() const;
+    [[nodiscard]] std::chrono::milliseconds targetChunkUploadDuration() const;
 
     void saveGeometry(QWidget *w);
     void restoreGeometry(QWidget *w);
 
     // how often the check about new versions runs
-    std::chrono::milliseconds updateCheckInterval(const QString &connection = QString()) const;
+    [[nodiscard]] std::chrono::milliseconds updateCheckInterval(const QString &connection = QString()) const;
 
     // skipUpdateCheck completely disables the updater and hides its UI
-    bool skipUpdateCheck(const QString &connection = QString()) const;
+    [[nodiscard]] bool skipUpdateCheck(const QString &connection = QString()) const;
     void setSkipUpdateCheck(bool, const QString &);
 
     // autoUpdateCheck allows the user to make the choice in the UI
-    bool autoUpdateCheck(const QString &connection = QString()) const;
+    [[nodiscard]] bool autoUpdateCheck(const QString &connection = QString()) const;
     void setAutoUpdateCheck(bool, const QString &);
 
     /** Query-parameter 'updatesegment' for the update check, value between 0 and 99.
         Used to throttle down desktop release rollout in order to keep the update servers alive at peak times.
         See: https://github.com/nextcloud/client_updater_server/pull/36 */
-    int updateSegment() const;
+    [[nodiscard]] int updateSegment() const;
 
-    QString updateChannel() const;
+    [[nodiscard]] QString updateChannel() const;
     void setUpdateChannel(const QString &channel);
 
+    [[nodiscard]] QString overrideServerUrl() const;
+    void setOverrideServerUrl(const QString &url);
+
+    [[nodiscard]] QString overrideLocalDir() const;
+    void setOverrideLocalDir(const QString &localDir);
+
     void saveGeometryHeader(QHeaderView *header);
     void restoreGeometryHeader(QHeaderView *header);
 
-    QString certificatePath() const;
+    [[nodiscard]] QString certificatePath() const;
     void setCertificatePath(const QString &cPath);
-    QString certificatePasswd() const;
+    [[nodiscard]] QString certificatePasswd() const;
     void setCertificatePasswd(const QString &cPasswd);
 
     /** The client version that last used this settings file.
         Updated by configVersionMigration() at client startup. */
-    QString clientVersionString() const;
+    [[nodiscard]] QString clientVersionString() const;
     void setClientVersionString(const QString &version);
 
     /**  Returns a new settings pre-set in a specific group.  The Settings will be created
@@ -207,18 +217,18 @@ public:
     static void setupDefaultExcludeFilePaths(ExcludedFiles &excludedFiles);
 
 protected:
-    QVariant getPolicySetting(const QString &policy, const QVariant &defaultValue = QVariant()) const;
+    [[nodiscard]] QVariant getPolicySetting(const QString &policy, const QVariant &defaultValue = QVariant()) const;
     void storeData(const QString &group, const QString &key, const QVariant &value);
-    QVariant retrieveData(const QString &group, const QString &key) const;
+    [[nodiscard]] QVariant retrieveData(const QString &group, const QString &key) const;
     void removeData(const QString &group, const QString &key);
-    bool dataExists(const QString &group, const QString &key) const;
+    [[nodiscard]] bool dataExists(const QString &group, const QString &key) const;
 
 private:
-    QVariant getValue(const QString &param, const QString &group = QString(),
+    [[nodiscard]] QVariant getValue(const QString &param, const QString &group = QString(),
         const QVariant &defaultValue = QVariant()) const;
     void setValue(const QString &key, const QVariant &value);
 
-    QString keychainProxyPasswordKey() const;
+    [[nodiscard]] QString keychainProxyPasswordKey() const;
 
 private:
     using SharedCreds = QSharedPointer<AbstractCredentials>;
