@@ -63,6 +63,11 @@ namespace FileSystem {
      */
     qint64 OWNCLOUDSYNC_EXPORT getSize(const QString &filename);
 
+    /**
+     * @brief Retrieve a file inode with csync
+     */
+    bool OWNCLOUDSYNC_EXPORT getInode(const QString &filename, quint64 *inode);
+
     /**
      * @brief Check if \a fileName has changed given previous size and mtime
      *
@@ -77,7 +82,7 @@ namespace FileSystem {
     /**
      * @brief Like !fileChanged() but with verbose logging if the file *did* change.
      */
-    bool verifyFileUnchanged(const QString &fileName,
+    bool OWNCLOUDSYNC_EXPORT verifyFileUnchanged(const QString &fileName,
         qint64 previousSize,
         time_t previousMtime);
 
