@@ -226,7 +226,7 @@ void SyncFileStatusTracker::slotAboutToPropagate(SyncFileItemVector &items)
     std::swap(_syncProblems, oldProblems);
 
     foreach (const SyncFileItemPtr &item, items) {
-        qCDebug(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction;
+        qCDebug(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction << item->_direction;
         _dirtyPaths.remove(item->destination());
 
         if (hasErrorStatus(*item)) {
