@@ -196,7 +196,7 @@ QString Theme::version() const
 
 QString Theme::configFileName() const
 {
-    return QStringLiteral(APPLICATION_EXECUTABLE ".cfg");
+    return QStringLiteral(APPLICATION_CONFIG_NAME ".cfg");
 }
 
 #ifndef TOKEN_AUTH_ONLY
@@ -343,6 +343,41 @@ QString Theme::hidpiFileName(const QString &iconName, const QColor &backgroundCo
 Theme::Theme()
     : QObject(nullptr)
 {
+#if defined(Q_OS_WIN)
+    // Windows does not provide a dark theme for Win32 apps so let's come up with a palette
+    // Credit to https://github.com/Jorgen-VikingGod/Qt-Frameless-Window-DarkStyle
+
+    reserveDarkPalette.setColor(QPalette::Window, QColor(53, 53, 53));
+    reserveDarkPalette.setColor(QPalette::WindowText, Qt::white);
+    reserveDarkPalette.setColor(QPalette::Disabled, QPalette::WindowText,
+                                QColor(127, 127, 127));
+    reserveDarkPalette.setColor(QPalette::Base, QColor(42, 42, 42));
+    reserveDarkPalette.setColor(QPalette::AlternateBase, QColor(66, 66, 66));
+    reserveDarkPalette.setColor(QPalette::ToolTipBase, Qt::white);
+    reserveDarkPalette.setColor(QPalette::ToolTipText, QColor(53, 53, 53));
+    reserveDarkPalette.setColor(QPalette::Text, Qt::white);
+    reserveDarkPalette.setColor(QPalette::Disabled, QPalette::Text, QColor(127, 127, 127));
+    reserveDarkPalette.setColor(QPalette::Dark, QColor(35, 35, 35));
+    reserveDarkPalette.setColor(QPalette::Shadow, QColor(20, 20, 20));
+    reserveDarkPalette.setColor(QPalette::Button, QColor(53, 53, 53));
+    reserveDarkPalette.setColor(QPalette::ButtonText, Qt::white);
+    reserveDarkPalette.setColor(QPalette::Disabled, QPalette::ButtonText,
+                                QColor(127, 127, 127));
+    reserveDarkPalette.setColor(QPalette::BrightText, Qt::red);
+    reserveDarkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
+    reserveDarkPalette.setColor(QPalette::Highlight, QColor(42, 130, 218));
+    reserveDarkPalette.setColor(QPalette::Disabled, QPalette::Highlight, QColor(80, 80, 80));
+    reserveDarkPalette.setColor(QPalette::HighlightedText, Qt::white);
+    reserveDarkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText,
+                                QColor(127, 127, 127));
+#endif
+
+#ifdef APPLICATION_SERVER_URL_ENFORCE
+    _forceOverrideServerUrl = true;
+#endif
+#ifdef APPLICATION_SERVER_URL
+    _overrideServerUrl = QString::fromLatin1(APPLICATION_SERVER_URL);
+#endif
 }
 
 // If this option returns true, the client only supports one folder to sync.
@@ -383,20 +418,17 @@ QString Theme::conflictHelpUrl() const
 
 QString Theme::overrideServerUrl() const
 {
-#ifdef APPLICATION_SERVER_URL
-    return QString::fromLatin1(APPLICATION_SERVER_URL);
-#else
-    return QString();
-#endif
+    return _overrideServerUrl;
 }
 
 bool Theme::forceOverrideServerUrl() const
 {
-#ifdef APPLICATION_SERVER_URL_ENFORCE
-    return true;
-#else
-    return false;
-#endif
+    return _forceOverrideServerUrl;
+}
+
+bool Theme::startLoginFlowAutomatically() const
+{
+    return _startLoginFlowAutomatically;
 }
 
 bool Theme::enableStaplingOCSP() const
@@ -417,6 +449,15 @@ bool Theme::forbidBadSSL() const
 #endif
 }
 
+bool Theme::doNotUseProxy() const
+{
+#ifdef DO_NOT_USE_PROXY
+    return true;
+#else
+    return false;
+#endif
+}
+
 QString Theme::forceConfigAuthType() const
 {
     return QString();
@@ -767,11 +808,16 @@ QString Theme::versionSwitchOutput() const
     return helpText;
 }
 
-bool Theme::isDarkColor(const QColor &color)
+double Theme::getColorDarkness(const QColor &color)
 {
     // account for different sensitivity of the human eye to certain colors
-    double treshold = 1.0 - (0.299 * color.red() + 0.587 * color.green() + 0.114 * color.blue()) / 255.0;
-    return treshold > 0.5;
+    const double threshold = 1.0 - (0.299 * color.red() + 0.587 * color.green() + 0.114 * color.blue()) / 255.0;
+    return threshold;
+}
+
+bool Theme::isDarkColor(const QColor &color)
+{
+    return getColorDarkness(color) > 0.5;
 }
 
 QColor Theme::getBackgroundAwareLinkColor(const QColor &backgroundColor)
@@ -796,7 +842,8 @@ void Theme::replaceLinkColorStringBackgroundAware(QString &linkString)
 
 void Theme::replaceLinkColorString(QString &linkString, const QColor &newColor)
 {
-    linkString.replace(QRegularExpression("(<a href|<a style='color:#([a-zA-Z0-9]{6});' href)"), QString::fromLatin1("<a style='color:%1;' href").arg(newColor.name()));
+    static const QRegularExpression linkRegularExpression("(<a href|<a style='color:#([a-zA-Z0-9]{6});' href)");
+    linkString.replace(linkRegularExpression, QString::fromLatin1("<a style='color:%1;' href").arg(newColor.name()));
 }
 
 QIcon Theme::createColorAwareIcon(const QString &name, const QPalette &palette)
@@ -865,19 +912,71 @@ bool Theme::enforceVirtualFilesSyncFolder() const
     return ENFORCE_VIRTUAL_FILES_SYNC_FOLDER && vfsMode != OCC::Vfs::Off;
 }
 
-QColor Theme::errorBoxTextColor() const
+QColor Theme::defaultColor()
 {
-    return QColor{"white"};
+    return QColor{NEXTCLOUD_BACKGROUND_COLOR};
 }
 
-QColor Theme::errorBoxBackgroundColor() const
+void Theme::connectToPaletteSignal()
 {
-    return QColor{"red"};
+    if (!_paletteSignalsConnected) {
+        if (const auto ptr = qobject_cast<QGuiApplication *>(QGuiApplication::instance())) {
+            connect(ptr, &QGuiApplication::paletteChanged, this, &Theme::systemPaletteChanged);
+            connect(ptr, &QGuiApplication::paletteChanged, this, &Theme::darkModeChanged);
+            _paletteSignalsConnected = true;
+        }
+    }
 }
 
-QColor Theme::errorBoxBorderColor() const
-{ 
-    return QColor{"black"};
+QPalette Theme::systemPalette()
+{
+    connectToPaletteSignal();
+#if defined(Q_OS_WIN)
+    if(darkMode()) {
+        return reserveDarkPalette;
+    }
+#endif
+    return QGuiApplication::palette();
+}
+
+bool Theme::darkMode()
+{
+    connectToPaletteSignal();
+// Windows: Check registry for dark mode
+#if defined(Q_OS_WIN)
+    const auto darkModeSubkey = QStringLiteral("Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize");
+    if (Utility::registryKeyExists(HKEY_CURRENT_USER, darkModeSubkey) &&
+        !Utility::registryGetKeyValue(HKEY_CURRENT_USER, darkModeSubkey, QStringLiteral("AppsUseLightTheme")).toBool()) {
+        return true;
+    }
+
+    return false;
+#else
+    return Theme::isDarkColor(QGuiApplication::palette().window().color());
+#endif
+}
+
+void Theme::setOverrideServerUrl(const QString &overrideServerUrl)
+{
+    if (_overrideServerUrl != overrideServerUrl) {
+        _overrideServerUrl = overrideServerUrl;
+        emit overrideServerUrlChanged();
+    }
+}
+void Theme::setForceOverrideServerUrl(bool forceOverride)
+{
+    if (_forceOverrideServerUrl != forceOverride) {
+        _forceOverrideServerUrl = forceOverride;
+        emit forceOverrideServerUrlChanged();
+    }
+}
+
+void Theme::setStartLoginFlowAutomatically(bool startLoginFlowAuto)
+{
+    if (_startLoginFlowAutomatically != startLoginFlowAuto) {
+        _startLoginFlowAutomatically = startLoginFlowAuto;
+        emit startLoginFlowAutomaticallyChanged();
+    }
 }
 
 } // end namespace client
