@@ -199,24 +199,27 @@ void OCC::HydrationJob::slotCheckFolderEncryptedMetadata(const QJsonDocument &js
     // TODO: the following code is borrowed from PropagateDownloadEncrypted (see HydrationJob::onNewConnection() for explanation of next steps)
     qCDebug(lcHydration) << "Metadata Received reading" << e2eMangledName();
     const QString filename = e2eMangledName();
-    auto meta = new FolderMetadata(_account, json.toJson(QJsonDocument::Compact));
-    const QVector<EncryptedFile> files = meta->files();
+    const FolderMetadata metadata(_account, json.toJson(QJsonDocument::Compact));
 
-    EncryptedFile encryptedInfo = {};
+    if (metadata.isMetadataSetup()) {
+        const QVector<EncryptedFile> files = metadata.files();
 
-    const QString encryptedFileExactName = e2eMangledName().section(QLatin1Char('/'), -1);
-    for (const EncryptedFile &file : files) {
-        if (encryptedFileExactName == file.encryptedFilename) {
-            EncryptedFile encryptedInfo = file;
-            encryptedInfo = file;
+        EncryptedFile encryptedInfo = {};
 
-            qCDebug(lcHydration) << "Found matching encrypted metadata for file, starting download" << _requestId << _folderPath;
-            _transferDataSocket = _transferDataServer->nextPendingConnection();
-            _job = new GETEncryptedFileJob(_account, _remotePath + e2eMangledName(), _transferDataSocket, {}, {}, 0, encryptedInfo, this);
+        const QString encryptedFileExactName = e2eMangledName().section(QLatin1Char('/'), -1);
+        for (const EncryptedFile &file : files) {
+            if (encryptedFileExactName == file.encryptedFilename) {
+                EncryptedFile encryptedInfo = file;
+                encryptedInfo = file;
 
-            connect(qobject_cast<GETEncryptedFileJob *>(_job), &GETEncryptedFileJob::finishedSignal, this, &HydrationJob::onGetFinished);
-            _job->start();
-            return;
+                qCDebug(lcHydration) << "Found matching encrypted metadata for file, starting download" << _requestId << _folderPath;
+                _transferDataSocket = _transferDataServer->nextPendingConnection();
+                _job = new GETEncryptedFileJob(_account, _remotePath + e2eMangledName(), _transferDataSocket, {}, {}, 0, encryptedInfo, this);
+
+                connect(qobject_cast<GETEncryptedFileJob *>(_job), &GETEncryptedFileJob::finishedSignal, this, &HydrationJob::onGetFinished);
+                _job->start();
+                return;
+            }
         }
     }
 
@@ -226,24 +229,28 @@ void OCC::HydrationJob::slotCheckFolderEncryptedMetadata(const QJsonDocument &js
 
 void OCC::HydrationJob::cancel()
 {
-    Q_ASSERT(_signalSocket);
-
     _isCancelled = true;
     if (_job) {
         _job->cancel();
     }
 
-    _signalSocket->write("cancelled");
-    _signalSocket->close();
-    _transferDataSocket->close();
+    if (_signalSocket) {
+        _signalSocket->write("cancelled");
+        _signalSocket->close();
+    }
 
+    if (_transferDataSocket) {
+        _transferDataSocket->close();
+    }
     emitFinished(Cancelled);
 }
 
 void OCC::HydrationJob::emitFinished(Status status)
 {
     _status = status;
-    _signalSocket->close();
+    if (_signalSocket) {
+        _signalSocket->close();
+    }
 
     if (status == Success) {
         connect(_transferDataSocket, &QLocalSocket::disconnected, this, [=] {
@@ -253,7 +260,10 @@ void OCC::HydrationJob::emitFinished(Status status)
         _transferDataSocket->disconnectFromServer();
         return;
     }
-    _transferDataSocket->close();
+
+    if (_transferDataSocket) {
+        _transferDataSocket->close();
+    }
 
     emit finished(this);
 }
@@ -282,7 +292,10 @@ void OCC::HydrationJob::finalize(OCC::VfsCfApi *vfs)
 {
     // Mark the file as hydrated in the sync journal
     SyncJournalFileRecord record;
-    _journal->getFileRecord(_folderPath, &record);
+    if (!_journal->getFileRecord(_folderPath, &record)) {
+        qCWarning(lcHydration) << "could not get file from local DB" << _folderPath;
+        return;
+    }
     Q_ASSERT(record.isValid());
     if (!record.isValid()) {
         qCWarning(lcHydration) << "Couldn't find record to update after hydration" << _requestId << _folderPath;
@@ -300,11 +313,23 @@ void OCC::HydrationJob::finalize(OCC::VfsCfApi *vfs)
         return;
     }
 
-    record._type = ItemTypeFile;
+    switch(_status) {
+    case Success:
+        record._type = ItemTypeFile;
+        break;
+    case Error:
+    case Cancelled:
+        record._type = CSyncEnums::ItemTypeVirtualFile;
+        break;
+    };
+
     // store the actual size of a file that has been decrypted as we will need its actual size when dehydrating it if requested
     record._fileSize = FileSystem::getSize(localPath() + folderPath());
 
-    _journal->setFileRecord(record);
+    const auto result = _journal->setFileRecord(record);
+    if (!result) {
+        qCWarning(lcHydration) << "Error when setting the file record to the database" << record._path << result.error();
+    }
 }
 
 void OCC::HydrationJob::onGetFinished()
