@@ -14,12 +14,15 @@
 
 #include "vfs_suffix.h"
 
-#include <QFile>
-
 #include "syncfileitem.h"
 #include "filesystem.h"
 #include "common/syncjournaldb.h"
 
+#include <QFile>
+#include <QLoggingCategory>
+
+Q_LOGGING_CATEGORY(lcVfsSuffix, "nextcloud.sync.vfs.suffix", QtInfoMsg)
+
 namespace OCC {
 
 VfsSuffix::VfsSuffix(QObject *parent)
@@ -45,12 +48,17 @@ void VfsSuffix::startImpl(const VfsSetupParams &params)
     // that are not marked as a virtual file. These could be real .owncloud
     // files that were synced before vfs was enabled.
     QByteArrayList toWipe;
-    params.journal->getFilesBelowPath("", [&toWipe](const SyncJournalFileRecord &rec) {
+    if (!params.journal->getFilesBelowPath("", [&toWipe](const SyncJournalFileRecord &rec) {
         if (!rec.isVirtualFile() && rec._path.endsWith(APPLICATION_DOTVIRTUALFILE_SUFFIX))
             toWipe.append(rec._path);
-    });
-    for (const auto &path : toWipe)
-        params.journal->deleteFileRecord(path);
+    })) {
+        qWarning() << "Could not get files below path \"\" from local DB";
+    }
+    for (const auto &path : toWipe) {
+        if (!params.journal->deleteFileRecord(path)) {
+            qWarning() << "Failed to delete file record from local DB" << path;
+        }
+    }
 }
 
 void VfsSuffix::stop()
@@ -69,7 +77,7 @@ bool VfsSuffix::isHydrating() const
 Result<void, QString> VfsSuffix::updateMetadata(const QString &filePath, time_t modtime, qint64, const QByteArray &)
 {
     if (modtime <= 0) {
-        return {tr("Error updating metadata due to invalid modified time")};
+        return {tr("Error updating metadata due to invalid modification time")};
     }
 
     FileSystem::setModTime(filePath, modtime);
@@ -79,7 +87,7 @@ Result<void, QString> VfsSuffix::updateMetadata(const QString &filePath, time_t
 Result<void, QString> VfsSuffix::createPlaceholder(const SyncFileItem &item)
 {
     if (item._modtime <= 0) {
-        return {tr("Error updating metadata due to invalid modified time")};
+        return {tr("Error updating metadata due to invalid modification time")};
     }
 
     // The concrete shape of the placeholder is also used in isDehydratedPlaceholder() below
@@ -153,6 +161,12 @@ bool VfsSuffix::statTypeVirtualFile(csync_file_stat_t *stat, void *)
     return false;
 }
 
+bool VfsSuffix::setPinState(const QString &folderPath, PinState state)
+{
+    qCDebug(lcVfsSuffix) << "setPinState" << folderPath << state;
+    return setPinStateInDb(folderPath, state);
+}
+
 Vfs::AvailabilityResult VfsSuffix::availability(const QString &folderPath)
 {
     return availabilityInDb(folderPath);
